@@ -25,7 +25,7 @@ from PIL import Image
 import re
 import urllib2
 
-__version__ = '0.0.25'
+__version__ = '0.0.26'
 
 def write_report(error):
     filename = os.path.join(CACHE_PATH,'crash_report')
@@ -60,11 +60,12 @@ KHWEETEUR_IDENTICA_CONSUMER_SECRET = '236fa46bf3f65fabdb1fd34d63c26d28'
 SCREENNAMEROLE = 20
 
 class KhweeteurDBus(dbus.service.Object):
+
     @dbus.service.method("net.khertan.khweeteur",
                          in_signature='', out_signature='')
     def show(self):
-        self.win.activateWindow()
         self.win.tweetsModel.getNewAndReset()
+        self.win.activateWindow()
 
     @dbus.service.method("net.khertan.khweeteur",
                          in_signature='s', out_signature='')
@@ -98,7 +99,7 @@ class KhweeteurNotification(QObject):
                           icon,
                           title,
                           message,
-                          ['default','test'],
+                          ['default',],
                           {'category':category,
                           'desktop-entry':'khweeteur',
                           'dbus-callback-default':'net.khertan.khweeteur /net/khertan/khweeteur net.khertan.khweeteur show',
@@ -112,7 +113,7 @@ class KhweeteurNotification(QObject):
                           icon,
                           title,
                           message,
-                          ['default','test'],
+                          ['default',],
                           {'category':category,
                           'desktop-entry':'khweeteur',
                           'dbus-callback-default':'net.khertan.khweeteur /net/khertan/khweeteur net.khertan.khweeteur show_search(%s)' % (keyword,),
@@ -1312,9 +1313,7 @@ class KhweeteurWin(QMainWindow):
         counter=self.tweetsModel.getNew()
         
         if (counter>0) and (self.settings.value('useNotification').toBool()) and not (self.isActiveWindow()):
-            if self.search_keyword:
-                pass
-            else:
+            if self.search_keyword == None:
                 self.notifications.notify('Khweeteur',str(counter)+' new tweet(s)',count=counter)
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
